@@ -1,5 +1,6 @@
 #include "mainwindowmaemo.h"
 #include "ui_mainwindowmaemo.h"
+#include "dabout.h"
 
 MainWindowMaemo::MainWindowMaemo(QWidget *parent) :
     QMainWindow(parent),
@@ -104,7 +105,7 @@ void MainWindowMaemo::on_btnSearch_clicked(
 	)
 {
     if (!ui->edtPackage->text().simplified().isEmpty()){
-	download("http://maemo.dadablog.net/AppStats.php?package="+ui->edtPackage->text()+"&os=fremantle");
+	download("http://maemo.dadablog.net/AppStats.php?package="+ui->edtPackage->text().simplified()+"&os=fremantle");
 
 	movie = new QMovie(":/loading.gif");
 
@@ -188,4 +189,22 @@ void MainWindowMaemo::downloadFinished(QNetworkReply *reply)
 void MainWindowMaemo::on_edtPackage_textChanged(const QString &arg1)
 {
     ui->edtPackage->setText(arg1.toLower());
+    ui->edtExtras->clear();
+    ui->edtExtrasTesting->clear();
+    ui->edtExtrasDevel->clear();
+    ui->edtTotal->clear();
+}
+
+void MainWindowMaemo::on_actionAbout_triggered(){
+    DAbout *d=new DAbout(0);
+    d->exec();
+    delete d;
+}
+
+void MainWindowMaemo::on_actionClear_triggered(){
+    ui->edtPackage->clear();
+    ui->edtExtras->clear();
+    ui->edtExtrasTesting->clear();
+    ui->edtExtrasDevel->clear();
+    ui->edtTotal->clear();
 }
