@@ -35,6 +35,10 @@ private slots:
 
     void on_edtPackage_textChanged(const QString &arg1);
 
+    void on_actionAbout_triggered();
+
+    void on_actionClear_triggered();
+
 private:
     Ui::MainWindowMaemo *ui;
     QNetworkAccessManager *netAccessMan;
